@@ -129,7 +129,9 @@ class MainHandler(web.RequestHandler):
 
             content_insert = f"""
 INSERT INTO sysio (
-ip,plotc,mvplotc,cpu_count,cpu_percent,cache_percent,slab_percent,swap_percent,disk_percent,iowait_percent,memory_percent,net_read_mb_s,net_write_mb_s,disk_read_mb_s,disk_write_mb_s,cpu_usage,net_fds,version,stamp
+ip,plotc,mvplotc,cpu_count,cpu_percent,
+cache_percent,slab_percent,swap_percent,disk_percent,iowait_percent,memory_percent,
+net_read_mb_s,net_write_mb_s,disk_read_mb_s,disk_write_mb_s,net_fds,version,stamp
 ) VALUES(
             '{remote_ip}',
             {int(j['plotcount'])},
